"""Docstring
    Data preparation module
"""
import logging

DEFAULT_PARTITIONS = 1

logging.basicConfig(level=logging.INFO, format="%(message)s")

__version__ = "0.2.2"
